| Title: | Interface to the Australian Statistical Geography Standard |
|---|---|
| Description: | The Australian Statistical Geography Standard ('ASGS') is a set of shapefiles by the Australian Bureau of Statistics. This package provides an interface to those shapefiles, as well as methods for converting coordinates to shapefiles. |
| Authors: | Hugh Parsonage [aut, cre] |
| Maintainer: | Hugh Parsonage <[email protected]> |
| License: | MPL |
| Version: | 0.3.3 |
| Built: | 2026-05-22 06:02:37 UTC |
| Source: | https://github.com/hughparsonage/asgs.foyer |
The ASGS package provides a nearly comprehensive set of shapefiles, both unmodified and simplified from the Australian Bureau of Statistics. The ASGS package is over 700 MB, so cannot be hosted on CRAN. This function allows the package to be distributed almost as conveniently as through CRAN.
Should you find ASGS lacks some shapefile that you require, please file an issue requesting it be added.
Note that the package is quite large and provides no limits on access, so it is preferred that distribution occur as far as possible via other channels to ensure the method of access provided here is sustainable.
install_ASGS( temp.tar.gz = tempfile(fileext = ".tar.gz"), overwrite = FALSE, lib = .libPaths()[1], repos = getOption("repos"), type = getOption("pkgType", "source"), ..., .reinstalls = 4L, url.tar.gz = NULL, verbose = FALSE )install_ASGS( temp.tar.gz = tempfile(fileext = ".tar.gz"), overwrite = FALSE, lib = .libPaths()[1], repos = getOption("repos"), type = getOption("pkgType", "source"), ..., .reinstalls = 4L, url.tar.gz = NULL, verbose = FALSE )
temp.tar.gz |
A file to save the ASGS tarball after download. Since the package is quite large, it may be prudent to set this to a non-temporary file so that subsequent attempts to reinstall do not require additional downloads. |
overwrite |
(logical, default: |
lib, repos, type
|
Passed to |
... |
Other arguments passed to |
.reinstalls |
Number of times to attempt to install any (absent) dependencies of |
url.tar.gz |
The URL of the tarball to be downloaded. Not normally needed by users, but may be in case the link becomes fallow, and a new one becomes available before the release of a new package entirely. If set to special value |
verbose |
(logical, default: |
temp.tar.gz, invisibly.
Determine whether coordinates lie in a given statistical area.
latlon2SA( lat, lon, to = c("STE", "SA2", "SA1", "SA3", "SA4"), yr = c("2016", "2011"), return = c("v", "sp"), NAME = TRUE, .shapefile = NULL )latlon2SA( lat, lon, to = c("STE", "SA2", "SA1", "SA3", "SA4"), yr = c("2016", "2011"), return = c("v", "sp"), NAME = TRUE, .shapefile = NULL )
lat, lon
|
Numeric vector representing coordinates in decimal degrees. Coordinates south of the equator have |
to |
The statistical area to convert to. |
yr |
The year of the statistical area. |
return |
Whether to return an atomic vector |
NAME |
(logical, default: |
.shapefile |
If specified, an arbitrary shapefile containing the statistical areas to locate. |
The statistical area that contains each point.
latlon2SA(-35.3, 149.2, to = "STE", yr = "2016")latlon2SA(-35.3, 149.2, to = "STE", yr = "2016")
State shapefile
STE_2016_simpleSTE_2016_simple
An object of class SpatialPolygonsDataFrame with 9 rows and 4 columns.